@@ -41,6 +41,8 @@
                                        BAOBAB_CHART_TYPE, \
                                        BaobabChartPrivate))
 
+#define SNAPSHOT_DEF_FILENAME_FORMAT "%s-disk-usage"
+
 G_DEFINE_ABSTRACT_TYPE (BaobabChart, baobab_chart, GTK_TYPE_WIDGET);
 
 enum
@@ -53,8 +55,6 @@ enum
 
 struct _BaobabChartPrivate
 {
-  gboolean summary_mode;
-
   guint name_column;
   guint size_column;
   guint info_column;
@@ -243,7 +243,6 @@ baobab_chart_init (BaobabChart *chart)
   priv = BAOBAB_CHART_GET_PRIVATE (chart);
   chart->priv = priv;
 
-  priv->summary_mode = TRUE;
   priv->model = NULL;
   priv->max_depth = BAOBAB_CHART_MAX_DEPTH;
   priv->name_column = 0;
@@ -530,21 +529,6 @@ baobab_chart_get_items (GtkWidget *chart, GtkTreePath *root)
   /* Create first item */
   node = baobab_chart_add_item (chart, 0, 0, 100, initial_iter);
 
-  /* If summary mode, insert a new item that will become root */
-  if (priv->summary_mode)
-    {
-      item = (BaobabChartItem *) node->data;
-      g_free (item->size);
-      item->size = NULL;
-
-      child_node = baobab_chart_add_item (chart, 1, 0, size, initial_iter);
-      child_item = (BaobabChartItem *) child_node->data;
-      child_item->parent = node;
-      child_item->name = item->name;
-
-      item->name = NULL;
-    }
-
   /* Iterate through childs building the list */
   class = BAOBAB_CHART_GET_CLASS (chart);
 
@@ -1667,6 +1651,9 @@ baobab_chart_save_snapshot (GtkWidget *chart)
   GtkWidget *opt_menu;
   gchar *sel_type;
   gchar *filename;
+  gchar *def_filename;
+
+  BaobabChartItem *item;
 
   g_return_if_fail (BAOBAB_IS_CHART (chart));
 
@@ -1689,6 +1676,8 @@ baobab_chart_save_snapshot (GtkWidget *chart)
       return;
     }
 
+  priv = BAOBAB_CHART (chart)->priv;
+
   /* Popup the File chooser dialog */
   fs_dlg = gtk_file_chooser_dialog_new (_("Save Snapshot"),
                                         NULL,
@@ -1698,6 +1687,12 @@ baobab_chart_save_snapshot (GtkWidget *chart)
                                         GTK_STOCK_SAVE,
                                         GTK_RESPONSE_ACCEPT, NULL);
 
+  item = (BaobabChartItem *) priv->first_item->data;
+  def_filename = g_strdup_printf (SNAPSHOT_DEF_FILENAME_FORMAT, item->name);
+
+  gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (fs_dlg), def_filename);
+  g_free (def_filename);
+
   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fs_dlg),
                                        g_get_home_dir ());
 
@@ -1732,6 +1727,13 @@ baobab_chart_save_snapshot (GtkWidget *chart)
     {
       filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (fs_dlg));
       sel_type = gtk_combo_box_get_active_text (GTK_COMBO_BOX (opt_menu));
+      if (! g_str_has_suffix (filename, sel_type))
+        {
+          gchar *tmp;
+          tmp = filename;
+          filename = g_strjoin (".", filename, sel_type, NULL);
+          g_free (tmp);
+        }
       gdk_pixbuf_save (pixbuf, filename, sel_type, NULL, NULL);
 
       g_free (filename);
@@ -1742,48 +1744,6 @@ baobab_chart_save_snapshot (GtkWidget *chart)
   g_object_unref (pixbuf);
 }
 
-/**
- * baobab_chart_set_summary_mode:
- * @chart: the #BaobabChart to set summary mode to.
- * @summary_mode: boolean specifying TRUE is summary mode is on.
- *
- * Toggles on/off the summary mode (the initial mode that shows general state
- * before any scan has been made).
- *
- * Fails if @chart is not a #BaobabChart.
- **/
-void
-baobab_chart_set_summary_mode (GtkWidget *chart,
-                               gboolean summary_mode)
-{
-  BaobabChartPrivate *priv;
-
-  g_return_if_fail (BAOBAB_IS_CHART (chart));
-
-  priv = BAOBAB_CHART_GET_PRIVATE (chart);
-  priv->summary_mode = summary_mode;
-}
-
-/**
- * baobab_chart_get_summary_mode:
- * @chart: the #BaobabChart to obtain summary mode from.
- *
- * Returns a boolean representing whether the chart is in summary mode (the 
- * initial mode that shows general state before any scan has been made).
- *
- * Fails if @chart is not a #BaobabChart.
- **/
-gboolean
-baobab_chart_get_summary_mode (GtkWidget *chart)
-{
-  BaobabChartPrivate *priv;
-
-  g_return_val_if_fail (BAOBAB_IS_CHART (chart), FALSE);
-
-  priv = BAOBAB_CHART_GET_PRIVATE (chart);
-  return priv->summary_mode;
-}
-
 /**
  * baobab_chart_is_frozen:
  * @chart: the #BaobabChart to ask if frozen.
