@@ -74,24 +74,28 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 		NULL
 	};
 	
-	const gchar *license =
-    	"This program is free software; you can redistribute it and/or "
+	const gchar *license[] = {
+    	N_("This program is free software; you can redistribute it and/or "
     	"modify it under the terms of the GNU General Public License as "
     	"published by the Free Software Foundation; either version 2 of "
-    	"the License, or (at your option) any later version.\n"
-    	"\n"
-    	"This program is distributed in the hope that it will be useful, "
+    	"the License, or (at your option) any later version."),
+
+    	N_("This program is distributed in the hope that it will be useful, "
     	"but WITHOUT ANY WARRANTY; without even the implied warranty of "
     	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU "
-    	"General Public License for more details.\n"
-    	"\n"
-    	"You should have received a copy of the GNU General Public License "
-    	"along with this program; if not, write to the Free Software "
-    	"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA "
-    	"02111-1307, USA.\n";
+    	"General Public License for more details."),
+
+	N_("You should have received a copy of the GNU General Public License "
+	"along with this program; if not, write to the Free Software Foundation, Inc., 51 "
+	"Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA")
+	};
 
 
-	static const gchar copyright[] = "Fabio Marzocca <thesaltydog@gmail.com> \xc2\xa9 2005-2008";
+	gchar *license_trans = g_strjoin ("\n\n", _(license[0]), 
+                                   _(license[1]),
+                                   _(license[2]), NULL);
+
+	static const gchar copyright[] = "Fabio Marzocca <thesaltydog@gmail.com> \xc2\xa9 2005-2009";
 
 	gtk_show_about_dialog (NULL,
 			       "name", _("Baobab"),
@@ -100,12 +104,13 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 			       "version", VERSION,
 			       "copyright", copyright,
 			       "logo-icon-name", "baobab",
-			       "license", license,
+			       "license", license_trans,
 			       "authors", authors, 
 			       "translator-credits",
 			       _("translator-credits"), 
 			       "wrap-license", TRUE,
 			        NULL);
+	g_free (license_trans);
 }
 
 void
@@ -232,54 +237,11 @@ trash_dir_cb (GtkMenuItem *pmenu, gpointer dummy)
 				    5, &filesize, -1);
 		gtk_tree_store_remove (GTK_TREE_STORE (baobab.model),
 				       &iter);
-		if (baobab.bbEnableHomeMonitor)
-			contents_changed ();
 	}
 
 	g_object_unref (file);
 }
 
-void
-volume_changed (GVolumeMonitor *volume_monitor,
-                GVolume        *volume,
-                gpointer        user_data)
-{
-	/* filesystem has changed (mounted or unmounted device) */
-	baobab_get_filesystem (&g_fs);
-	set_label_scan (&g_fs);
-	show_label ();
-}
-
-void
-contents_changed_cb (GFileMonitor      *file_monitor,
-              	     GFile             *child,
-              	     GFile             *other_file,
-              	     GFileMonitorEvent  event_type,
-              	     gpointer           user_data)
-
-{
-	gchar *excluding;
-
-	if (!baobab.bbEnableHomeMonitor)
-		return;
-
-	if (baobab.CONTENTS_CHANGED_DELAYED)
-		return;
-
-	excluding = g_file_get_basename (child);
-	if (strcmp (excluding, ".recently-used") == 0   ||
-	    strcmp (excluding, ".gnome2_private") == 0  ||
-	    strcmp (excluding, ".xsession-errors") == 0 ||
-	    strcmp (excluding, ".bash_history") == 0    ||
-	    strcmp (excluding, ".gconfd") == 0) {
-		g_free (excluding);
-		return;
-	}
-	g_free (excluding);
-
-	baobab.CONTENTS_CHANGED_DELAYED = TRUE;
-}
-
 void
 on_pref_menu (GtkMenuItem *menuitem, gpointer user_data)
 {
@@ -322,12 +284,12 @@ on_view_tb_activate (GtkCheckMenuItem *checkmenuitem,
 }
 
 void
-on_view_sb_activate (GtkCheckMenuItem *checkmenuitem,
-                     gpointer          user_data) 
+on_view_sb_activate (GtkToggleAction *action,
+                     gpointer         user_data) 
 {
 	gboolean visible;
 
-	visible = gtk_check_menu_item_get_active (checkmenuitem);
+	visible = gtk_toggle_action_get_active (action);
 	set_statusbar_visible (visible);
 
 	gconf_client_set_bool (baobab.gconf_client,
@@ -339,7 +301,7 @@ on_view_sb_activate (GtkCheckMenuItem *checkmenuitem,
 void
 on_helpcontents_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
-	baobab_help_display (GTK_WINDOW (baobab.window), "baobab.xml", NULL);
+	baobab_help_display (GTK_WINDOW (baobab.window), "baobab", NULL);
 }
 
 void 
